unit Status;
(*
 This sample unit is part of Table Scanner package
 Copyright 1997-2000 by Demian [demianH@bigfoot.com]
*)

{$X+}

interface

uses
  Classes,SysUtils,Forms,StdCtrls,Buttons,ExtCtrls,Dialogs,Controls,
  {$IFDEF WIN32}Windows,{$ELSE}WinProcs,WinTypes,{$ENDIF}MakeDB;

type
  TFormStatus = class(TForm)
    LabelTitle: TLabel;
    LabelTablesT: TLabel;
    LabelTables: TLabel;
    LabelCurrentT: TLabel;
    LabelCurrent: TLabel;
    LabelOperationT: TLabel;
    LabelOperation: TLabel;
    LabelActionT: TLabel;
    LabelAction: TLabel;
    BitBtnCancel: TBitBtn;
    ImageIcon: TImage;
    BevelMain: TBevel;
    ShapeProgress: TShape;
    procedure BitBtnCancelClick(Sender: TObject);
  end;

var
  FormStatus: TFormStatus;

function DoOnCheckTable(const Sender: TScanInfo): boolean; export;

implementation

{$R *.DFM}

{______________________________________________________________________________}
function DoOnCheckTable(const Sender: TScanInfo): boolean;
(*
 This function is called by TBLSCN.DLL and must return a boolean value:
 True, to continue table checking, or False, to abort table checking.
*)

  procedure ConfirmFix;
  var
    szWarning: array[0..255] of char;
  begin
    {'saFix' occurs before any repair is attempted on a corrupted data file (.DB,.DBF).
     As the repair is not guaranteed to work in all cases, 'saFix' should be used
     to back the data file up, before procceeding (it's up to your application to
     supply backup/restore routines).}
    FormStatus.LabelOperation.Caption := 'Fix';
    StrPCopy(szWarning,format('Table %s seems to be corrupted. %s is now going to try to fix it. '+
                              'CAUTION: it''s strongly advisable to back the table up before procceeding.'#10#10+
                              'Do you wish to procceed?',
                              [ChangeFileExt(Sender.TableName,''),Application.Title]));
    Application.NormalizeTopMosts;
    if MessageBox(0,szWarning,'Warning',MB_ICONEXCLAMATION+MB_DEFBUTTON2+MB_YESNO) <> IDYes then
      FormStatus.Tag := -1;
    Application.RestoreTopMosts;
  end;

begin
  with FormStatus,Sender do
  case Action of
    {'saStart' occurs before any tables are checked. Should be used to perform
     any required initialization.}
    saStart : begin
                FormStatus := TFormStatus.Create(nil);
                with FormStatus do begin
                  Caption := Application.Title;
                  ImageIcon.Picture.Graphic := Application.Icon;
                  LabelOperation.Caption := 'Start';
                  ShapeProgress.Width := 0;
                  Show;
                end;
              end;
    {'saFinish' occurs after all tables are checked. Should be used to perform
     any required finalization.
     NOTE: This action occurs even when an exception is raised during checking}
    saFinish: begin
                LabelOperation.Caption := 'Finish';
                result := Tag <> -1;
                if not result then
                   ShowMessage('Operation terminated by user');
                FormStatus.Free;
                Exit;
              end;
  else
    {Following actions occur during table checking}
    LabelTables.Caption := IntToStr(TableIndex)+'/'+IntToStr(TableCount);
    LabelCurrent.Caption := TableName;
    ShapeProgress.Width := (BevelMain.Width-20)*(TableIndex) div TableCount;
    case Action of
      saVerify: LabelOperation.Caption := 'Verify';
      saCreate: LabelOperation.Caption := 'Create';
      saRedo  : LabelOperation.Caption := 'Redo';
      saModify: LabelOperation.Caption := 'Modify';
      saFix   : ConfirmFix;
    end;
    LabelAction.Caption := BDEMessage;
  end;
  {Aborts table checking if user clicks Cancel button}
  result := FormStatus.Tag <> -1;
end;

{______________________________________________________________________________}
procedure TFormStatus.BitBtnCancelClick(Sender: TObject);
begin
  {Set flag indicating that user clicked Cancel button}
  Tag := -1;
end;

end.
